generated files are a nono in cvs
[privoxy.git] / cgi.c
diff --git a/cgi.c b/cgi.c
index e196097..f63cca3 100644 (file)
--- a/cgi.c
+++ b/cgi.c
@@ -1,4 +1,4 @@
-const char cgi_rcs[] = "$Id: cgi.c,v 1.48 2002/03/08 17:47:07 jongfoster Exp $";
+const char cgi_rcs[] = "$Id: cgi.c,v 1.52 2002/03/24 15:23:33 jongfoster Exp $";
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/cgi.c,v $
@@ -12,7 +12,7 @@ const char cgi_rcs[] = "$Id: cgi.c,v 1.48 2002/03/08 17:47:07 jongfoster Exp $";
  * 
  *
  * Copyright   :  Written by and Copyright (C) 2001 the SourceForge
- *                IJBSWA team.  http://ijbswa.sourceforge.net
+ *                Privoxy team.  http://ijbswa.sourceforge.net
  *
  *                Based on the Internet Junkbuster originally written
  *                by and Copyright (C) 1997 Anonymous Coders and 
@@ -38,6 +38,22 @@ const char cgi_rcs[] = "$Id: cgi.c,v 1.48 2002/03/08 17:47:07 jongfoster Exp $";
  *
  * Revisions   :
  *    $Log: cgi.c,v $
+ *    Revision 1.52  2002/03/24 15:23:33  jongfoster
+ *    Name changes
+ *
+ *    Revision 1.51  2002/03/24 13:25:43  swa
+ *    name change related issues
+ *
+ *    Revision 1.50  2002/03/16 23:54:06  jongfoster
+ *    Adding graceful termination feature, to help look for memory leaks.
+ *    If you enable this (which, by design, has to be done by hand
+ *    editing config.h) and then go to http://i.j.b/die, then the program
+ *    will exit cleanly after the *next* request.  It should free all the
+ *    memory that was used.
+ *
+ *    Revision 1.49  2002/03/13 00:27:04  jongfoster
+ *    Killing warnings
+ *
  *    Revision 1.48  2002/03/08 17:47:07  jongfoster
  *    Adding comments
  *
@@ -329,7 +345,12 @@ const char cgi_h_rcs[] = CGI_H_VERSION;
 static const struct cgi_dispatcher cgi_dispatchers[] = {
    { "",
          cgi_default,
-         "Junkbuster main page" },
+         "Privoxy main page" },
+#ifdef FEATURE_GRACEFUL_TERMINATION
+   { "die", 
+         cgi_die,  
+         "<b>Shut down</b> - <font color=red size='+1'>Do not deploy this build in a production environment, this is a one click Denial Of Service attack!!!</font>" }, 
+#endif
    { "show-status", 
          cgi_show_status,  
          "Show information about the current configuration" }, 
@@ -344,7 +365,7 @@ static const struct cgi_dispatcher cgi_dispatchers[] = {
          "Show which actions apply to a URL and why"  },
    { "toggle",
          cgi_toggle, 
-         "Toggle JunkBuster on or off" },
+         "Toggle Privoxy on or off" },
 #ifdef FEATURE_CGI_EDIT_ACTIONS
    { "edit-actions",
          cgi_edit_actions, 
@@ -468,13 +489,15 @@ const char image_pattern_data[] =
  * 1x1 transparant PNG.
  */
 const char image_blank_data[] =
-   "\211\120\116\107\015\012\032\012\000\000\000\015\111\110\104"
-   "\122\000\000\000\002\000\000\000\002\010\002\000\000\000\375"
-   "\324\232\163\000\000\000\006\142\113\107\104\000\310\000\310"
-   "\000\310\052\045\225\037\000\000\000\027\111\104\101\124\170"
-   "\332\143\374\377\377\377\311\223\047\031\116\234\070\361\377"
-   "\377\177\000\112\335\012\257\162\103\306\335\000\000\000\000"
-   "\111\105\116\104\256\102\140\202o";
+ "\211\120\116\107\015\012\032\012\000\000\000\015\111\110\104\122"
+ "\000\000\000\004\000\000\000\004\010\006\000\000\000\251\361\236"
+ "\176\000\000\000\007\164\111\115\105\007\322\003\013\020\073\070"
+ "\013\025\036\203\000\000\000\011\160\110\131\163\000\000\013\022"
+ "\000\000\013\022\001\322\335\176\374\000\000\000\004\147\101\115"
+ "\101\000\000\261\217\013\374\141\005\000\000\000\033\111\104\101"
+ "\124\170\332\143\070\161\342\304\207\377\377\377\347\302\150\006"
+ "\144\016\210\146\040\250\002\000\042\305\065\221\270\027\131\110"
+ "\000\000\000\000\111\105\116\104\256\102\140\202";
 #else
 
 /*
@@ -841,15 +864,15 @@ void cgi_init_error_messages(void)
 {
    memset(cgi_error_memory_response, '\0', sizeof(*cgi_error_memory_response));
    cgi_error_memory_response->head =
-      "HTTP/1.0 500 Internal JunkBuster Proxy Error\r\n"
+      "HTTP/1.0 500 Internal Privoxy Error\r\n"
       "Content-Type: text/html\r\n"
       "\r\n";
    cgi_error_memory_response->body =
       "<html>\r\n"
-      "<head><title>500 Internal JunkBuster Proxy Error</title></head>\r\n"
+      "<head><title>500 Internal Privoxy Error</title></head>\r\n"
       "<body>\r\n"
-      "<h1>500 Internal JunkBuster Proxy Error</h1>\r\n"
-      "<p>JunkBuster <b>ran out of memory</b> while processing your request.</p>\r\n"
+      "<h1>500 Internal Privoxy Error</h1>\r\n"
+      "<p>Privoxy <b>ran out of memory</b> while processing your request.</p>\r\n"
       "<p>Please contact your proxy administrator, or try again later</p>\r\n"
       "</body>\r\n"
       "</html>\r\n";
@@ -911,13 +934,13 @@ jb_err cgi_error_no_template(struct client_state *csp,
                              const char *template_name)
 {
    static const char status[] =
-      "500 Internal JunkBuster Proxy Error";
+      "500 Internal Privoxy Error";
    static const char body_prefix[] =
       "<html>\r\n"
-      "<head><title>500 Internal JunkBuster Proxy Error</title></head>\r\n"
+      "<head><title>500 Internal Privoxy Error</title></head>\r\n"
       "<body>\r\n"
-      "<h1>500 Internal JunkBuster Proxy Error</h1>\r\n"
-      "<p>JunkBuster encountered an error while processing your request:</p>\r\n"
+      "<h1>500 Internal Privoxy Error</h1>\r\n"
+      "<p>Privoxy encountered an error while processing your request:</p>\r\n"
       "<p><b>Could not load template file <code>";
    static const char body_suffix[] =
       "</code></b></p>\r\n"
@@ -925,10 +948,10 @@ jb_err cgi_error_no_template(struct client_state *csp,
       "<p>If you are the proxy administrator, please put the required file "
       "in the <code><i>(confdir)</i>/templates</code> directory.  The "
       "location of the <code><i>(confdir)</i></code> directory "
-      "is specified in the main JunkBuster <code>config</code> "
-      "file.  (It's typically the JunkBuster install directory"
+      "is specified in the main Privoxy <code>config</code> "
+      "file.  (It's typically the Privoxy install directory"
 #ifndef _WIN32
-      ", or <code>/etc/junkbuster/</code>"
+      ", or <code>/etc/privoxy/</code>"
 #endif /* ndef _WIN32 */
       ").</p>\r\n"
       "</body>\r\n"
@@ -1121,7 +1144,7 @@ struct http_response *finish_http_response(struct http_response *rsp)
    {
       /*
        * Set Expires to about 10 min into the future so it'll get reloaded
* occasionally, e.g. if IJB gets upgraded.
        */
 
       if (!err)
@@ -1121,7 +1144,7 @@ struct http_response *finish_http_response(struct http_response *rsp)
       /*
        * Set Expires to about 10 min into the future so it'll get reloaded
-       * occasionally, e.g. if IJB gets upgraded.
+       * occasionally, e.g. if Privoxy gets upgraded.
        */
 